# DiBISO plot

A python library to plot bibliometric data made at the [DiBISO](https://www.bibliotheques.universite-paris-saclay.fr/en/department-libraries-information-and-open-science-dibiso-and-its-missions)
(Department of Libraries, Information and Open Science) at the Université Paris-Saclay.

The library contains the following submodules:

  - `biso`: plot data for the BiSO (Open-Science Report)

Documentation: https://github.com/dibiso-upsaclay/dibisoplot

Repository URL: https://github.com/dibiso-upsaclay/dibisoplot


Romain THOMAS 2025  
DiBISO - Université Paris-Saclay